@@ -1,7 +1,7 @@
 package File::Digest;
 
 our $DATE = '2016-11-23'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -147,11 +147,11 @@ File::Digest - Calculate file checksum/digest (using various algorithms)
 
 =head1 VERSION
 
-This document describes version 0.005 of File::Digest (from Perl distribution File-Digest), released on 2016-11-23.
+This document describes version 0.006 of File::Digest (from Perl distribution File-Digest), released on 2016-11-23.
 
 =head1 SYNOPSIS
 
- use File::Digest qw(digest_files check_file_digest);
+ use File::Digest qw(digest_files);
 
  my $res = digest_files(
      files => ["file1", "file2"],
